@@ -1,13 +1,13 @@
+#![allow(dead_code)]
 #[derive(Clone)]
-
-pub struct Matrix<T: Clone> {
+struct Matrix<T: Clone> {
     size: (usize, usize),
     data: Vec<T>,
     default: T
 }
 
 impl<T: Clone> Matrix<T> {
-    pub fn new(new_width: usize, new_height: usize, new_default: T) -> Self {
+    fn new(new_width: usize, new_height: usize, new_default: T) -> Self {
         Matrix {
             size: (new_width, new_height),
             data: vec![new_default.clone(); new_width * new_height],
